# better-project-forecast

[![Build Status](https://travis-ci.org/cmheisel/better-project-forecast.svg?branch=master)](https://travis-ci.org/cmheisel/better-project-forecast) [![Coverage Status](https://coveralls.io/repos/github/cmheisel/better-project-forecast/badge.svg?branch=master)](https://coveralls.io/github/cmheisel/better-project-forecast?branch=master)

Averages suck, improve your project forecasting
